@@ -3,13 +3,10 @@
 """
 # import functools
 import math
+from functools import partial
 
-from .utils import (  # clean_form, clean_update_form,
-    Decode,
-    Objects,
-    Response,
-    fixed_id_column,
-)
+from .utils import Objects  # clean_form, clean_update_form,
+from .utils import Decode, Response, fixed_id_column
 from .utils.sql_where import Filters as SQLFilters
 
 try:
@@ -60,6 +57,7 @@ class SQL:
         self.where = self.Q.where
         self.columns = self.table.columns.keys()
         self.c = self.table.c
+        self.to_obj = partial(Objects.sql, self.columns)
 
     @staticmethod
     def id_decode(unique_id):
@@ -74,6 +72,17 @@ class SQL:
             return await self.create_one(form)
         return await self.create_many(form, return_items)
 
+    async def _create_one_row(self, form: dict) -> Response:
+        """(Base) Create Single-Row."""
+        return_value = Response()
+        try:
+            sql_query = self.table.insert().values(**form)
+            return_value.data = await self.database.execute(sql_query)
+        except Exception as error:
+            return_value.error = True
+            return_value.error_message = str(error)
+        return return_value
+
     async def create_one(self, form: dict):
         """Create Single-Row."""
         return_value = await self._create_one_row(form)
@@ -81,30 +90,6 @@ class SQL:
             return_value.data = await self.get_by(_id=return_value.data)
         return return_value
 
-    async def create_many(self, forms: list, return_items: bool):
-        """Create Single-Row."""
-        if return_items:
-            all_ids = []
-            for form in forms:
-                return_value = await self._create_one_row(form)
-                if return_value.data:
-                    all_ids.append(return_value.data)
-            sql_ids_in = self.Q.where("_id", "in", all_ids)
-            items = await self.database.fetch_all(self.Q.select(sql_ids_in))
-            return Response(data=Objects.sql(items), count=len(items))
-        return await self._create_many_rows(forms)
-
-    async def _create_one_row(self, form: dict) -> Response:
-        """(Base) Create Single-Row."""
-        return_value = Response()
-        try:
-            sql_query = self.table.insert(form)
-            return_value.data = await self.database.execute(sql_query)
-        except Exception as error:
-            return_value.error = True
-            return_value.error_message = str(error)
-        return return_value
-
     async def _create_many_rows(self, form: list):
         """(Base) Create Multiple-Row."""
         return_value = Response()
@@ -118,6 +103,19 @@ class SQL:
             return_value.error_message = str(error)
         return return_value
 
+    async def create_many(self, forms: list, return_items: bool):
+        """Create Single-Row."""
+        if return_items:
+            all_ids = []
+            for form in forms:
+                return_value = await self._create_one_row(form)
+                if return_value.data:
+                    all_ids.append(return_value.data)
+            sql_ids_in = self.Q.where("_id", "in", all_ids)
+            items = await self.database.fetch_all(self.Q.select(sql_ids_in))
+            return Response(data=self.to_obj(items), count=len(items))
+        return await self._create_many_rows(forms)
+
     async def update(self, unique_ids: list[str], form: dict):
         """Update Multiple/Single-Row(s)"""
         return_value = Response()
@@ -161,26 +159,26 @@ class SQL:
         """Get Single-Row from Database Table by ID"""
         query = self.Q.filter_by(_id=Decode.sql(ID))
         item = await self.database.fetch_one(self.Q.select(query))
-        return Objects.sql(item)
+        return self.to_obj(item)
 
     async def get_by(self, **kwargs):
         """Get Single-Row from Database Table by <Keyword-Arguments>"""
         kwargs = fixed_id_column(kwargs)
         query = self.Q.filter_by(**kwargs)
         item = await self.database.fetch_one(self.Q.select(query))
-        return Objects.sql(item)
+        return self.to_obj(item)
 
     async def find_one(self, query):
         """Get Single-Row from Database Table by <SQLAlchemy-BinaryExpression>"""
         item = await self.database.fetch_one(self.Q.select(query))
-        return Objects.sql(item)
+        return self.to_obj(item)
 
     async def all(
         self,
     ):
         """Get All-Rows from Database Table"""
         items = await self.database.fetch_all(self.Q.select())
-        return Response(data=Objects.sql(items), count=len(items), pages=1)
+        return Response(data=self.to_obj(items), count=len(items), pages=1)
 
     async def find(
         self,
@@ -197,7 +195,7 @@ class SQL:
             count = await self.database.fetch_val(query.count)
             _limit = limit or 1
             pages = int(math.ceil(count / _limit))
-            return Response(data=Objects.sql(items), count=count, pages=pages)
+            return Response(data=self.to_obj(items), count=count, pages=pages)
         except Exception as e:
             print(e)
             return Response(data=[], count=0, pages=0)
